"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
var codeeditor_1 = require("@jupyterlab/codeeditor");
var coreutils_1 = require("@jupyterlab/coreutils");
var _1 = require(".");
/**
 * The mime type service for CodeMirror.
 */
var CodeMirrorMimeTypeService = (function () {
    function CodeMirrorMimeTypeService() {
    }
    /**
     * Returns a mime type for the given language info.
     *
     * #### Notes
     * If a mime type cannot be found returns the defaul mime type `text/plain`, never `null`.
     */
    CodeMirrorMimeTypeService.prototype.getMimeTypeByLanguage = function (info) {
        var mode;
        if (info.codemirror_mode) {
            mode = _1.Mode.findBest(info.codemirror_mode);
            if (mode) {
                return mode.mime;
            }
        }
        mode = _1.Mode.findByMIME(info.mimetype || '');
        if (mode) {
            return info.mimetype;
        }
        var ext = info.file_extension || '';
        ext = ext.split('.').slice(-1)[0];
        mode = _1.Mode.findByExtension(ext || '');
        if (mode) {
            return mode.mime;
        }
        mode = _1.Mode.findByName(info.name || '');
        return mode ? mode.mime : codeeditor_1.IEditorMimeTypeService.defaultMimeType;
    };
    /**
     * Returns a mime type for the given file path.
     *
     * #### Notes
     * If a mime type cannot be found returns the defaul mime type `text/plain`, never `null`.
     */
    CodeMirrorMimeTypeService.prototype.getMimeTypeByFilePath = function (path) {
        if (coreutils_1.PathExt.extname(path) === '.ipy') {
            return 'text/x-python';
        }
        var mode = _1.Mode.findByFileName(path);
        return mode ? mode.mime : codeeditor_1.IEditorMimeTypeService.defaultMimeType;
    };
    return CodeMirrorMimeTypeService;
}());
exports.CodeMirrorMimeTypeService = CodeMirrorMimeTypeService;
